@@ -3,6 +3,7 @@ from rift.core.condition import Cond
 from rift.core.loop import while_
 from rift.func.types.entity_base import Entity
 from rift.library.std import std
+from rift.logging import log_system
 from rift.runtime.config import Config, Mode
 from rift.types.bases import Builder, Cell, Int, Slice
 from rift.types.utils import Subscriptable, obtain_tmp
@@ -58,13 +59,14 @@ class Payload(metaclass=Subscriptable):
         if item in self._skipped_ones:
             n = self._skipped_ones[item]
             name = f"{self.f_name}_{item}"
+            if n is None:
+                return n
             return n.__assign__(name)
 
         if self.__data__ is None:
             # We have no data => user is probably building!
             name = f"{self.f_name}_{item}"
             return Entity(name=name)
-
         if not self._lazy or item not in self._items:
             # CASE I: The requested item is not a defined field
             # CASE II: Payload is not lazy
@@ -205,6 +207,7 @@ class Payload(metaclass=Subscriptable):
     def skip_tag(cls, from_):
         tag_len, _ = cls.tag_data()
         # from_.skip_bits_(tag_len)
+        log_system("DE", "skipping tag len={len}", len=tag_len)
         from_.uint_(tag_len)
 
     def to_builder(self, builder):
